package org.implab.gradle.containers;

import org.gradle.api.Plugin;
import org.gradle.api.Project;
import org.gradle.api.plugins.ExtraPropertiesExtension;
import org.implab.gradle.containers.tasks.BuildImage;
import org.implab.gradle.containers.tasks.ComposeExec;
import org.implab.gradle.containers.tasks.ComposeRm;
import org.implab.gradle.containers.tasks.ComposeStop;
import org.implab.gradle.containers.tasks.ComposeUp;
import org.implab.gradle.containers.tasks.ExecContainer;
import org.implab.gradle.containers.tasks.PushImage;
import org.implab.gradle.containers.tasks.RmContainer;
import org.implab.gradle.containers.tasks.RunContainer;
import org.implab.gradle.containers.tasks.SaveImage;
import org.implab.gradle.containers.tasks.StopContainer;
import org.implab.gradle.containers.tasks.TagImage;

public abstract class ContainerBasePlugin implements Plugin<Project>, ProjectMixin {
    public static final String CONTAINER_EXTENSION_NAME = "container";

    private ContainerExtension containerExtension;

    ContainerExtension getContainerExtension() {
        if (containerExtension == null)
            throw new IllegalStateException();
        return containerExtension;
    }

    void exportClasses(Project project, Class<?>... classes) {
        ExtraPropertiesExtension extras = project.getExtensions().getExtraProperties();
        for (var clazz : classes)
            extras.set(clazz.getSimpleName(), clazz);
    }

    @Override
    public void apply(Project project) {

        containerExtension = extension(CONTAINER_EXTENSION_NAME, ContainerExtension.class);

        exportClasses(
                project,
                BuildImage.class, PushImage.class, SaveImage.class, TagImage.class, RunContainer.class,
                StopContainer.class, ExecContainer.class, RmContainer.class, ComposeUp.class, ComposeExec.class,
                ComposeRm.class, ComposeStop.class);

    }

}
