package org.implab.gradle.containers.dsl;

import java.util.Map;
import java.util.Optional;

public class MapEntry<T> {
    private final Map<String, Object> map;
    private final String key;
    private final Class<T> clazz;

    public MapEntry(Map<String, Object> map, String key, Class<T> clazz) {
        this.map = map;
        this.key = key;
        this.clazz = clazz;
    }

    public boolean has() {
        var value = map.get(key);
        return value != null;
    }

    public T get() {
        if (!has())
            throw new IllegalStateException();
        return clazz.cast(map.get(key));
    }

    public void put(T value) {
        map.put(key, value);
    }

    public void remove() {
        map.remove(key);
    }

    public Optional<T> optional() {
        return has() ? Optional.of(get()) : Optional.empty();
    }
}
