package org.implab.gradle.containers.tasks;

import java.io.File;
import java.util.Optional;

import org.gradle.api.file.RegularFile;
import org.gradle.api.file.RegularFileProperty;
import org.gradle.api.provider.SetProperty;
import org.gradle.api.tasks.Internal;
import org.implab.gradle.containers.ComposeExtension;

/**
 * Base task for compose subtasks like 'uo', 'rm', 'stop', etc.
 */
public interface ComposeTaskMixin extends TaskServices {

    /** The list of profiles to use with the compose commands */
    @Internal
    SetProperty<String> getProfiles();

    /**
     * The primary compose files. This task is executed regardless whether these
     * files was changed.
     */
    @Internal
    RegularFileProperty getComposeFile();

    default void applyComposeConvention() {
        onlyIf(task -> getComposeFile().map(RegularFile::getAsFile).map(File::exists).getOrElse(false));
        Optional.ofNullable(getProject().getExtensions().findByType(ComposeExtension.class))
            .ifPresent(ext -> {
                getProfiles().set(ext.getProfiles());
                getComposeFile().set(ext.getComposeFile());
            });
        
    }
}
