package org.implab.gradle.containers.tasks;

import java.io.File;
import java.io.IOException;
import java.util.concurrent.ExecutionException;
import java.util.stream.Collectors;

import org.gradle.api.provider.Property;
import org.gradle.api.provider.Provider;
import org.gradle.api.provider.SetProperty;
import org.gradle.api.tasks.Internal;
import org.gradle.api.tasks.TaskAction;
import org.implab.gradle.containers.cli.Utils;

public abstract class RmContainer extends DockerCliTask implements TaskServices {

    @Internal
    public abstract Property<Boolean> getRemoveVolumes();

    @Internal
    public abstract Property<Boolean> getForce();

    @Internal
    public abstract SetProperty<String> getContainerIds();

    public RmContainer() {
        getRemoveVolumes().convention(true);
        getForce().convention(false);
        onlyIfReason("No containers specified", self -> getContainerIds().get().size() > 0);
    }

    public void fromIdFile(File file) {
        getContainerIds().add(provider(() -> Utils.readAll(file)));
    }

    public void fromIdFile(Provider<Object> file) {
        getContainerIds().add(file.map(Utils::normalizeFile).map(Utils::readAll));
    }

    @TaskAction
    public void run() throws InterruptedException, ExecutionException, IOException {
        var alive = getContainerIds().get().stream().filter(this::containerExists).collect(Collectors.toSet());

        if (alive.size() > 0)
            exec(docker().containerRm(alive, getRemoveVolumes().get(), getForce().get()));
        else
            getLogger().info("No containers left, nothing to do");
    }

}
