package org.implab.gradle.containers.tasks;

import org.gradle.api.Action;
import org.gradle.api.DefaultTask;
import org.gradle.api.file.RegularFileProperty;
import org.gradle.api.provider.MapProperty;
import org.gradle.api.tasks.Input;
import org.gradle.api.tasks.OutputFile;
import org.gradle.api.tasks.TaskAction;
import org.implab.gradle.containers.PropertiesMixin;
import org.implab.gradle.containers.cli.Utils;
import org.implab.gradle.containers.dsl.MapPropertyEntry;

import java.io.FileWriter;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import groovy.lang.Closure;

public abstract class WriteEnv extends DefaultTask implements PropertiesMixin {
    
    @Input
    public abstract MapProperty<String, String> getEnvironment();

    @OutputFile
    public abstract RegularFileProperty getEnvFile();

    public void env(Action<Map<String, String>> spec) {
        getEnvironment().putAll(provider(() -> {
            Map<String, String> args = new HashMap<>();
            spec.execute(args);
            getLogger().info("add buildArgs {}", args);
            return args;
        }));
    }

    public void env(Closure<Map<String, String>> spec) {
        env(Utils.wrapClosure(spec));
    }

    public MapPropertyEntry<String, String> env(String key) {
        return new MapPropertyEntry<String, String>(getEnvironment(), key, getProviders());
    }

    @TaskAction
    public void run() throws IOException {
        try (var writer = new FileWriter(getEnvFile().get().getAsFile())) {
            for (var entry : getEnvironment().get().entrySet()) {
                writer.write(entry.getKey());
                writer.write("=");
                writer.write(entry.getValue().replace("\n", "\\n"));
                writer.write("\n");
            }
        }
    }

    
}
